@@ -1,5 +1,10 @@
-"""Package with general repository related functions"""
+# This module is part of GitPython and is released under the
+# 3-Clause BSD License: https://opensource.org/license/bsd-3-clause/
+
+"""General repository-related functions."""
+
 from __future__ import annotations
+
 import os
 import stat
 from pathlib import Path
@@ -116,7 +121,7 @@ def find_submodule_git_dir(d: "PathLike") -> Optional["PathLike"]:
             if not osp.isabs(path):
                 path = osp.normpath(osp.join(osp.dirname(d), path))
             return find_submodule_git_dir(path)
-    # end handle exception
+    # END handle exception
     return None
 
 
